
# Class: gene grouping


any grouping of multiple genes or gene products

URI: [biolink:GeneGrouping](https://w3id.org/biolink/vocab/GeneGrouping)

![img](http://yuml.me/diagram/nofunky;dir:TB/class/\[GeneFamily]uses%20-.->\[GeneGrouping])

## Mixin for

 * [GeneFamily](GeneFamily.md) (mixin)  - any grouping of multiple genes or gene products related by common descent

## Referenced by class


## Attributes

